﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;

namespace Ascend
{
	/// <summary>
	/// Containter for animation frame data.
	/// </summary>
	public class AnimationFrame : ICloneable
	{
		#region Lifecycle
		/// <summary>
		/// Creates a default AnimationFrame instance.
		/// </summary>
		public AnimationFrame()
		{
			BonePoses = new List<ObjectPose>();
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the model pose associated with this frame.
		/// </summary>
		public ObjectPose ModelPose { get; set; }

		/// <summary>
		/// Gets the Bone poses associated with this frame.
		/// </summary>
		public List<ObjectPose> BonePoses { get; private set; }
		#endregion

		#region Public Methods
		/// <summary>
		/// Creates a deep copy of this AnimationFrame.
		/// </summary>
		public object Clone()
		{
			AnimationFrame clone = new AnimationFrame
			{
				ModelPose = (ModelPose != null) ? ModelPose.Clone() as ObjectPose : null,
			};
			
			clone.BonePoses = BonePoses.Select(p => p.Clone() as ObjectPose).ToList();

			return clone;
		}
		#endregion
	}
}
