﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
namespace Ascend
{
	/// <summary>
	/// An interval of frames over which an AnimatedSceneNode can animate.
	/// </summary>
	public struct FrameInterval
	{
		/// <summary>
		/// Creates a FrameInterval instance with starting and ending indices.
		/// </summary>
		/// <param name="start">Starting frame index.</param>
		/// <param name="end">Ending frame index.</param>
        /// <exception cref="ArgumentException">
        /// Thrown if <paramref name="start"/> is greater than <paramref name="end"/>.
        /// </exception>
		public FrameInterval(int start, int end)
		{
            if (start > end)
                throw new ArgumentException("Starting frame index cannot be greater than ending frame index.");

			Start = start;
			End = end;
		}

		/// <summary>
		/// The starting frame index.
		/// </summary>
		public int Start;
		
		/// <summary>
		/// The ending frame index.
		/// </summary>
		public int End;

		/// <summary>
		/// Gets the duration of this FrameInterval in frames.
		/// </summary>
		public int Length { get { return End - Start + 1; } }
	}
}
