﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Ascend
{
	/// <summary>
	/// Structure that defines how vertices are affected by a Bone.
	/// </summary>
	public struct VertexInfluence
	{
		#region Lifecycle
		/// <summary>
		/// Creates a VertexInfluence instance from given weight and set of vertices.
		/// </summary>
		/// <param name="weight">A value from 0 to 1 specifying the weight of this VertexInfluence.</param>
		/// <param name="vertices">The set of vertices affected by a Bone.</param>
		public VertexInfluence(double weight, List<int> vertices)
		{
			_weight = weight;
			_vertices = vertices;
		}
		#endregion

		#region Private Members
		private double _weight;
		private List<int> _vertices;
		#endregion

		/// <summary>
		/// The set of vertices affected by a Bone.
		/// </summary>
		public IList<int> Vertices { get { return _vertices.AsReadOnly(); } }

		/// <summary>
		/// The weight applied to transformations by this VertexInfluence.
		/// </summary>
		public double Weight { get { return _weight; } }
	}
}
