﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using System.Windows.Media.Media3D;

namespace Ascend
{
	/// <summary>
	/// Arguments for use in SceneNode mouse wheel event handlers.
	/// </summary>
	public class SceneNodeMouseWheelEventArgs : SceneNodeMouseEventArgs
	{
		#region Lifecycle
		internal SceneNodeMouseWheelEventArgs(MouseWheelEventArgs e, SceneViewer3D viewer, ModelSceneNode source, RayHitTestResult result)
			: base(e, viewer, source, result)
		{ }

		/// <summary>
		/// Creates a new SceneNodeMouseWheelEventArgs instance using the
		/// specified mouse device, timestamp, and wheel change amount.
		/// </summary>
		/// <param name="mouse">The mouse device associated with this event.</param>
		/// <param name="timestamp">The time when the input occurred.</param>
		/// <param name="delta">The amount the wheel has changed.</param>
		public SceneNodeMouseWheelEventArgs(MouseDevice mouse, int timestamp, int delta)
			: this(new MouseWheelEventArgs(mouse, timestamp, delta), null, null, null)
		{ }
		#endregion

		#region Properties
		/// <summary>
		/// Gets the amount that the mouse wheel has changed.
		/// </summary>
		public int Delta { get { return ((MouseWheelEventArgs)_sourceArgs).Delta; } }
		#endregion
	}
}