﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Media;
using System.Windows.Media.Media3D;

namespace Ascend
{
	/// <summary>
	/// A SceneNode that contains a Light.
	/// </summary>
	public class LightSceneNode : SceneNode
	{
		#region Lifecycle
		/// <summary>
		/// Creates a new default LightSceneNode instance.
		/// </summary>
		public LightSceneNode()
		{
			// Create default light content
			Data.Children.Add(new AmbientLight());
		}

		/// <summary>
		/// Creates a new LightSceneNode instance with given Light.
		/// </summary>
		/// <param name="light">The Light for the LightSceneNode.</param>
		public LightSceneNode(Light light)
			: this()
		{
			Light = light;
		}
		#endregion

		#region Properties
		private Light _light;
		/// <summary>
		/// Gets or sets the Light content of this LightSceneNode.
		/// </summary>
		public Light Light
		{
			get { return _light; }
			set
			{
				if (_light == value)
					return;

				_light = value;

				Data.Children[1] = (_light != null) ? _light : new AmbientLight();
			}
		}
		#endregion

		#region Public Methods
		/// <summary>
		/// Creates a deep copy of this LightSceneNode.
		/// </summary>
		public override object Clone()
		{
			LightSceneNode clone = new LightSceneNode();

			clone.Light = (Light != null) ? Light.Clone() : null;

			CloneProperties(clone);

			CloneChildren(clone);

			return clone;
		}
		#endregion
	}
}
