﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Ascend
{
	/// <summary>
	/// A class that describes the position, rotation and scale of an object.
	/// </summary>
	public class ObjectPose : ICloneable
	{
		#region Properties
		/// <summary>
		/// Gets or sets this ObjectPose's X coordinate.
		/// </summary>
		public double X { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Y coordinate.
		/// </summary>
		public double Y { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Z coordinate.
		/// </summary>
		public double Z { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's X-axis angle (roll) in degrees
		/// (Rotation convention is yaw-pitch-roll / YZX).
		/// </summary>
		public double AngleX { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Y-axis angle (yaw) in degrees
		/// (Rotation convention is yaw-pitch-roll / YZX).
		/// </summary>
		public double AngleY { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Z-axis angle (pitch) in degrees
		/// (Rotation convention is yaw-pitch-roll / YZX).
		/// </summary>
		public double AngleZ { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's X-axis scale factor.
		/// </summary>
		public double ScaleX { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Y-axis scale factor.
		/// </summary>
		public double ScaleY { get; set; }

		/// <summary>
		/// Gets or sets this ObjectPose's Z-axis scale factor.
		/// </summary>
		public double ScaleZ { get; set; }
		#endregion

		#region Public Methods
		/// <summary>
		/// Creates a deep copy of this ObjectPose.
		/// </summary>
		public object Clone()
		{
			return MemberwiseClone();
		}
		#endregion
	}

}
