﻿/*
	Copyright (c) 2013 Andrew Meyer

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
	associated documentation files (the "Software"), to deal in the Software without restriction,
	including without limitation the rights to use, copy, modify, merge, publish, distribute,
	sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial
	portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using Ascend;
using System.Windows.Forms;
using System.ComponentModel;
using System.Windows.Media.Media3D;

namespace AscendViewer
{
	public class ContentExplorerViewModel : ObservableObject
	{
		#region Lifecycle
		public ContentExplorerViewModel()
		{
			ExpandAllCommand = new InterfaceCommand(() =>
				{
					if (ContentNode != null)
					{
						foreach (var node in ContentNode.SelfAndDescendants())
							node.IsExpanded = true;
					}
				}
			);

			CollapseAllCommand = new InterfaceCommand(() =>
				{
					if (ContentNode != null)
					{
						foreach (var node in ContentNode.SelfAndDescendants())
							node.IsExpanded = false;
					}
				}
			);
		}
		#endregion

		#region Properties
		public ICommand ExpandAllCommand { get; private set; }
        public ICommand CollapseAllCommand { get; private set; }

        public Scene3D Scene { get; set; }

		private ContentNodeViewModel _contentNode;
		public ContentNodeViewModel ContentNode
		{
			get { return _contentNode; }
			set
			{
				if (_contentNode == value)
					return;

				_contentNode = value;
				NotifyPropertyChanged("ContentNode");
			}
		}

		private ContentNodeViewModel _selectedContentNode;
		public ContentNodeViewModel SelectedContentNode
		{
			get { return _selectedContentNode; }
			set
			{
				if (_selectedContentNode == value)
					return;

				_selectedContentNode = value;

				// Deselect all other content nodes
				foreach (var node in ContentNode.SelfAndDescendants().Where(n => n != _selectedContentNode))
					node.IsSelected = false;

				// Select and look at selected node
				_selectedContentNode.IsSelected = true;

				NotifyPropertyChanged("SelectedContentNode");

			}
		}

		private bool _isExpanded = false;
		public bool IsExpanded
		{
			get { return _isExpanded; }
			set
			{
				if (_isExpanded == value)
					return;

				_isExpanded = value;
				NotifyPropertyChanged("IsExpanded");
			}
		}

		private string _fileName;
		public string FileName
		{
			get { return _fileName; }
			set
			{
				if (_fileName == value)
					return;

				_fileName = value;
				NotifyPropertyChanged("FileName");
			}
		}
		#endregion
	}
}
