﻿using System.ComponentModel;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Media3D;
using Ascend;

namespace Demo01_GettingStarted
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		#region Lifecycle
		public MainWindow()
		{
			InitializeComponent();

			// Set data context for bindings
			DataContext = this;

			// Create our Scene3D object
			//
			// A Scene3D has two main components:
			//    A camera
			//    A root SceneNode
			Scene = new Scene3D();

			// Setup the camera
			Scene.Camera.Position = new Point3D(1, 1, 3);
			Scene.Camera.LookDirection = new Vector3D(-1, -1, -3);

			// Add an object to the Scene3D by attaching a child SceneNode
			// to the root SceneNode. Only SceneNodes that are
			// attached to the root SceneNode will be rendered.
			ModelSceneNode cube = new ModelSceneNode(ModelMaker.MakeCube(Colors.DodgerBlue));
			Scene.RenderRoot.Children.Add(cube);

			// Now add a light, so objects can be seen
			LightSceneNode light = new LightSceneNode(new DirectionalLight(Colors.White, new Vector3D(0, -1, -2)));

			// SceneNodes can be attached to other SceneNodes by either:
			//    Adding a SceneNode to another SceneNode's Children collection (the way the cube was added)
			//    Or by setting the Parent property of a SceneNode appropriately (see line below)
			light.Parent = Scene.RenderRoot;
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the Scene3D that is rendered.
		/// </summary>
		public Scene3D Scene { get; set; }
		#endregion
	}
}